@@ -1,8 +1,8 @@
-from ..base_service import BaseService
+from ..service import Service as BaseService
 
 class GCloudService(BaseService):
-    def __init__(self, config):
-        super().__init__(config)
+    def __init__(self, config, logger=None):
+        super().__init__(config, logger=logger)
         self.name = 'a-gcloud-service'
 
     def up(self):
